summaryrefslogtreecommitdiff
path: root/src/effectmanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/effectmanager.h')
-rw-r--r--src/effectmanager.h37
1 files changed, 23 insertions, 14 deletions
diff --git a/src/effectmanager.h b/src/effectmanager.h
index 4b349471..01c5a6b8 100644
--- a/src/effectmanager.h
+++ b/src/effectmanager.h
@@ -1,34 +1,38 @@
/*
- * The Mana World
- * Copyright 2004 The Mana World Development Team
+ * An effects manager
+ * Copyright (C) 2008 Fate <fate.tmw@googlemail.com>
+ * Copyright (C) 2008 Chuck Miller <shadowmil@gmail.com>
*
* This file is part of The Mana World.
*
- * The Mana World is free software; you can redistribute it and/or modify
+ * This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* any later version.
*
- * The Mana World is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with The Mana World; if not, write to the Free Software
+ * along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
-#ifndef _EFFECT_MANAGER_H
-#define _EFFECT_MANAGER_H
+#ifndef EFFECT_MANAGER_H
+#define EFFECT_MANAGER_H
-#include <string>
#include <list>
+#include <string>
+
+class Being;
class EffectManager
{
public:
- struct EffectDescription {
+ struct EffectDescription
+ {
int id;
std::string GFX;
std::string SFX;
@@ -38,16 +42,21 @@ class EffectManager
~EffectManager();
/**
* Triggers a effect with the id, at x,y
* returns true if ID exists
*/
- bool trigger(int id, int x = 0, int y = 0);
+ bool trigger(int id, Being* being);
+
+ /**
+ * Triggers a effect with the id, at
+ * the specified x and y coordinate.
+ */
+ bool trigger(int id, int x, int y);
private:
std::list<EffectDescription> mEffects;
-
};
extern EffectManager *effectManager;
-#endif // _EFFECT_MANAGER_H
+#endif // EFFECT_MANAGER_H
@@ -38,16 +42,21 @@ class EffectManager
~EffectManager();
/**
- * Triggers a effect with the id, at x,y
- * returns true if ID exists
+ * Triggers a effect with the id, at
+ * the specified being.
*/